# mikesh
This package provides an easy way of working with neutron spectra and neutron reaction cross-sections using Python. The package provides several classes that allow the user to regroup neutron spectra, calculate reaction rates or perform spectral adjustment.

WARNING: This package is in development, and not all intended features are implemented at the moment. 
